==> huaweicloudsdkcoc-3.1.120-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_resource_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListResourceResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'data': 'list[BatchListResourceResponseData]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'data': 'data',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, data=None, x_request_id=None):
        """ListResourceResponse

        The model defined in huaweicloud sdk

        :param data: 资源列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListResourceResponse, self).__init__()

        self._data = None
        self._x_request_id = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def data(self):
        """Gets the data of this ListResourceResponse.

        资源列表

        :return: The data of this ListResourceResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ListResourceResponse.

        资源列表

        :param data: The data of this ListResourceResponse.
        :type data: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        """
        self._data = data

    @property
    def x_request_id(self):
        """Gets the x_request_id of this ListResourceResponse.

        :return: The x_request_id of this ListResourceResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this ListResourceResponse.

        :param x_request_id: The x_request_id of this ListResourceResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListResourceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_resource_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListResourceResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'data': 'list[BatchListResourceResponseData]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'data': 'data',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, data=None, x_request_id=None):
        r"""ListResourceResponse

        The model defined in huaweicloud sdk

        :param data: 资源列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListResourceResponse, self).__init__()

        self._data = None
        self._x_request_id = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def data(self):
        r"""Gets the data of this ListResourceResponse.

        资源列表

        :return: The data of this ListResourceResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        """
        return self._data

    @data.setter
    def data(self, data):
        r"""Sets the data of this ListResourceResponse.

        资源列表

        :param data: The data of this ListResourceResponse.
        :type data: list[:class:`huaweicloudsdkcoc.v1.BatchListResourceResponseData`]
        """
        self._data = data

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this ListResourceResponse.

        :return: The x_request_id of this ListResourceResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this ListResourceResponse.

        :param x_request_id: The x_request_id of this ListResourceResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListResourceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
